==> servicecatalog-model-6.6.2-sources.jar: io/fabric8/servicecatalog/api/model/ServiceBrokerListFluent.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ServiceBrokerListFluent<A extends ServiceBrokerListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,ServiceBroker item);
  public A setToItems(Integer index,ServiceBroker item);
  public A addToItems(io.fabric8.servicecatalog.api.model.ServiceBroker... items);
  public A addAllToItems(Collection<ServiceBroker> items);
  public A removeFromItems(io.fabric8.servicecatalog.api.model.ServiceBroker... items);
  public A removeAllFromItems(Collection<ServiceBroker> items);
  public A removeMatchingFromItems(Predicate<ServiceBrokerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ServiceBroker> getItems();
  public List<ServiceBroker> buildItems();
  public ServiceBroker buildItem(Integer index);
  public ServiceBroker buildFirstItem();
  public ServiceBroker buildLastItem();
  public ServiceBroker buildMatchingItem(Predicate<ServiceBrokerBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ServiceBrokerBuilder> predicate);
  public A withItems(List<ServiceBroker> items);
  public A withItems(io.fabric8.servicecatalog.api.model.ServiceBroker... items);
  public Boolean hasItems();
  public ServiceBrokerListFluent.ItemsNested<A> addNewItem();
  public ServiceBrokerListFluent.ItemsNested<A> addNewItemLike(ServiceBroker item);
  public ServiceBrokerListFluent.ItemsNested<A> setNewItemLike(Integer index,ServiceBroker item);
  public ServiceBrokerListFluent.ItemsNested<A> editItem(Integer index);
  public ServiceBrokerListFluent.ItemsNested<A> editFirstItem();
  public ServiceBrokerListFluent.ItemsNested<A> editLastItem();
  public ServiceBrokerListFluent.ItemsNested<A> editMatchingItem(Predicate<ServiceBrokerBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ServiceBrokerFluent<ServiceBrokerListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/ServiceBrokerListFluent.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ServiceBrokerListFluent<A extends ServiceBrokerListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,ServiceBroker item);
  public A setToItems(int index,ServiceBroker item);
  public A addToItems(io.fabric8.servicecatalog.api.model.ServiceBroker... items);
  public A addAllToItems(Collection<ServiceBroker> items);
  public A removeFromItems(io.fabric8.servicecatalog.api.model.ServiceBroker... items);
  public A removeAllFromItems(Collection<ServiceBroker> items);
  public A removeMatchingFromItems(Predicate<ServiceBrokerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ServiceBroker> getItems();
  public List<ServiceBroker> buildItems();
  public ServiceBroker buildItem(int index);
  public ServiceBroker buildFirstItem();
  public ServiceBroker buildLastItem();
  public ServiceBroker buildMatchingItem(Predicate<ServiceBrokerBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ServiceBrokerBuilder> predicate);
  public A withItems(List<ServiceBroker> items);
  public A withItems(io.fabric8.servicecatalog.api.model.ServiceBroker... items);
  public Boolean hasItems();
  public ServiceBrokerListFluent.ItemsNested<A> addNewItem();
  public ServiceBrokerListFluent.ItemsNested<A> addNewItemLike(ServiceBroker item);
  public ServiceBrokerListFluent.ItemsNested<A> setNewItemLike(int index,ServiceBroker item);
  public ServiceBrokerListFluent.ItemsNested<A> editItem(int index);
  public ServiceBrokerListFluent.ItemsNested<A> editFirstItem();
  public ServiceBrokerListFluent.ItemsNested<A> editLastItem();
  public ServiceBrokerListFluent.ItemsNested<A> editMatchingItem(Predicate<ServiceBrokerBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ServiceBrokerFluent<ServiceBrokerListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
